Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComputeFileHash ¶
This is a separate function from ComputeHash because streaming the file contents into the hasher is more efficient than reading the entire file into memory at once, especially for larger files.
Types ¶
Click to show internal directories.
Click to hide internal directories.